summaryrefslogtreecommitdiff
path: root/deps/v8/src/heap
diff options
context:
space:
mode:
authorMichaël Zasso <targos@protonmail.com>2017-03-23 14:05:51 +0100
committerMichaël Zasso <targos@protonmail.com>2017-03-25 09:44:12 +0100
commit9c9e2d7f4a576310eb652a620db090f00a320243 (patch)
tree5a41e9dde9234264ac4196a1b34493d8e0a6fde5 /deps/v8/src/heap
parent07088e6fc1342b5581d9e6f7ce084308573e3139 (diff)
downloadandroid-node-v8-9c9e2d7f4a576310eb652a620db090f00a320243.tar.gz
android-node-v8-9c9e2d7f4a576310eb652a620db090f00a320243.tar.bz2
android-node-v8-9c9e2d7f4a576310eb652a620db090f00a320243.zip
deps: backport 3297130 from upstream V8
This fixes a build failure on Windows. Original commit message: Rename TypeFeedbackVector to FeedbackVector. ... and TypeFeedbackMetadata to FeedbackMetadata. BUG= Change-Id: I2556d1c2a8f37b8cf3d532cc98d973b6dc7e9e6c Reviewed-on: https://chromium-review.googlesource.com/439244 Commit-Queue: Igor Sheludko <ishell@chromium.org> Reviewed-by: Michael Starzinger <mstarzinger@chromium.org> Reviewed-by: Michael Stanton <mvstanton@chromium.org> Reviewed-by: Jaroslav Sevcik <jarin@chromium.org> Reviewed-by: Yang Guo <yangguo@chromium.org> Reviewed-by: Hannes Payer <hpayer@chromium.org> Cr-Commit-Position: refs/heads/master@{#42999} Refs: https://github.com/nodejs/v8/issues/4 PR-URL: https://github.com/nodejs/node/pull/11752 Reviewed-By: Ben Noordhuis <info@bnoordhuis.nl> Reviewed-By: Franziska Hinkelmann <franziska.hinkelmann@gmail.com>
Diffstat (limited to 'deps/v8/src/heap')
-rw-r--r--deps/v8/src/heap/heap-inl.h2
-rw-r--r--deps/v8/src/heap/heap.cc38
-rw-r--r--deps/v8/src/heap/heap.h6
-rw-r--r--deps/v8/src/heap/object-stats.cc10
4 files changed, 28 insertions, 28 deletions
diff --git a/deps/v8/src/heap/heap-inl.h b/deps/v8/src/heap/heap-inl.h
index 4d060f8e43..b8f3498b42 100644
--- a/deps/v8/src/heap/heap-inl.h
+++ b/deps/v8/src/heap/heap-inl.h
@@ -9,6 +9,7 @@
#include "src/base/platform/platform.h"
#include "src/counters-inl.h"
+#include "src/feedback-vector-inl.h"
#include "src/heap/heap.h"
#include "src/heap/incremental-marking-inl.h"
#include "src/heap/mark-compact.h"
@@ -22,7 +23,6 @@
#include "src/msan.h"
#include "src/objects-inl.h"
#include "src/objects/scope-info.h"
-#include "src/type-feedback-vector-inl.h"
namespace v8 {
namespace internal {
diff --git a/deps/v8/src/heap/heap.h b/deps/v8/src/heap/heap.h
index d8034891fc..e2f436a908 100644
--- a/deps/v8/src/heap/heap.h
+++ b/deps/v8/src/heap/heap.h
@@ -59,7 +59,7 @@ using v8::MemoryPressureLevel;
V(Map, heap_number_map, HeapNumberMap) \
V(Map, transition_array_map, TransitionArrayMap) \
V(FixedArray, empty_literals_array, EmptyLiteralsArray) \
- V(FixedArray, empty_type_feedback_vector, EmptyTypeFeedbackVector) \
+ V(FixedArray, empty_feedback_vector, EmptyFeedbackVector) \
V(FixedArray, empty_fixed_array, EmptyFixedArray) \
V(DescriptorArray, empty_descriptor_array, EmptyDescriptorArray) \
/* Entries beyond the first 32 */ \
@@ -95,7 +95,7 @@ using v8::MemoryPressureLevel;
V(Map, external_map, ExternalMap) \
V(Map, bytecode_array_map, BytecodeArrayMap) \
V(Map, module_info_map, ModuleInfoMap) \
- V(Map, type_feedback_vector_map, TypeFeedbackVectorMap) \
+ V(Map, feedback_vector_map, FeedbackVectorMap) \
/* String maps */ \
V(Map, native_source_string_map, NativeSourceStringMap) \
V(Map, string_map, StringMap) \
@@ -160,7 +160,7 @@ using v8::MemoryPressureLevel;
V(FixedArray, empty_sloppy_arguments_elements, EmptySloppyArgumentsElements) \
V(SeededNumberDictionary, empty_slow_element_dictionary, \
EmptySlowElementDictionary) \
- V(TypeFeedbackVector, dummy_vector, DummyVector) \
+ V(FeedbackVector, dummy_vector, DummyVector) \
V(PropertyCell, empty_property_cell, EmptyPropertyCell) \
V(WeakCell, empty_weak_cell, EmptyWeakCell) \
/* Protectors */ \
diff --git a/deps/v8/src/heap/object-stats.cc b/deps/v8/src/heap/object-stats.cc
index 9f534a20e4..1b9cdf5ecc 100644
--- a/deps/v8/src/heap/object-stats.cc
+++ b/deps/v8/src/heap/object-stats.cc
@@ -540,10 +540,10 @@ void ObjectStatsCollector::RecordSharedFunctionInfoDetails(
SharedFunctionInfo* sfi) {
FixedArray* scope_info = sfi->scope_info();
RecordFixedArrayHelper(sfi, scope_info, SCOPE_INFO_SUB_TYPE, 0);
- TypeFeedbackMetadata* feedback_metadata = sfi->feedback_metadata();
+ FeedbackMetadata* feedback_metadata = sfi->feedback_metadata();
if (!feedback_metadata->is_empty()) {
- RecordFixedArrayHelper(sfi, feedback_metadata,
- TYPE_FEEDBACK_METADATA_SUB_TYPE, 0);
+ RecordFixedArrayHelper(sfi, feedback_metadata, FEEDBACK_METADATA_SUB_TYPE,
+ 0);
}
if (!sfi->OptimizedCodeMapIsCleared()) {
@@ -568,7 +568,7 @@ void ObjectStatsCollector::RecordSharedFunctionInfoDetails(
if (literals != nullptr) {
RecordFixedArrayHelper(sfi, literals, LITERALS_ARRAY_SUB_TYPE, 0);
RecordFixedArrayHelper(sfi, literals->feedback_vector(),
- TYPE_FEEDBACK_VECTOR_SUB_TYPE, 0);
+ FEEDBACK_VECTOR_SUB_TYPE, 0);
}
}
}
@@ -578,7 +578,7 @@ void ObjectStatsCollector::RecordJSFunctionDetails(JSFunction* function) {
LiteralsArray* literals = function->literals();
RecordFixedArrayHelper(function, literals, LITERALS_ARRAY_SUB_TYPE, 0);
RecordFixedArrayHelper(function, literals->feedback_vector(),
- TYPE_FEEDBACK_VECTOR_SUB_TYPE, 0);
+ FEEDBACK_VECTOR_SUB_TYPE, 0);
}
void ObjectStatsCollector::RecordFixedArrayDetails(FixedArray* array) {
diff --git a/deps/v8/src/heap/heap.cc b/deps/v8/src/heap/heap.cc
index 478be1f03a..e84f56e076 100644
--- a/deps/v8/src/heap/heap.cc
+++ b/deps/v8/src/heap/heap.cc
@@ -17,6 +17,7 @@
#include "src/conversions.h"
#include "src/debug/debug.h"
#include "src/deoptimizer.h"
+#include "src/feedback-vector.h"
#include "src/global-handles.h"
#include "src/heap/array-buffer-tracker-inl.h"
#include "src/heap/code-stats.h"
@@ -41,7 +42,6 @@
#include "src/snapshot/serializer-common.h"
#include "src/snapshot/snapshot.h"
#include "src/tracing/trace-event.h"
-#include "src/type-feedback-vector.h"
#include "src/utils.h"
#include "src/v8.h"
#include "src/v8threads.h"
@@ -2269,7 +2269,7 @@ bool Heap::CreateInitialMaps() {
ALLOCATE_VARSIZE_MAP(FIXED_ARRAY_TYPE, scope_info)
ALLOCATE_VARSIZE_MAP(FIXED_ARRAY_TYPE, module_info)
- ALLOCATE_VARSIZE_MAP(FIXED_ARRAY_TYPE, type_feedback_vector)
+ ALLOCATE_VARSIZE_MAP(FIXED_ARRAY_TYPE, feedback_vector)
ALLOCATE_PRIMITIVE_MAP(HEAP_NUMBER_TYPE, HeapNumber::kSize, heap_number,
Context::NUMBER_FUNCTION_INDEX)
ALLOCATE_MAP(MUTABLE_HEAP_NUMBER_TYPE, HeapNumber::kSize,
@@ -2766,23 +2766,23 @@ void Heap::CreateInitialObjects() {
{
StaticFeedbackVectorSpec spec;
FeedbackVectorSlot slot = spec.AddLoadICSlot();
- DCHECK_EQ(slot, FeedbackVectorSlot(TypeFeedbackVector::kDummyLoadICSlot));
+ DCHECK_EQ(slot, FeedbackVectorSlot(FeedbackVector::kDummyLoadICSlot));
slot = spec.AddKeyedLoadICSlot();
DCHECK_EQ(slot,
- FeedbackVectorSlot(TypeFeedbackVector::kDummyKeyedLoadICSlot));
+ FeedbackVectorSlot(FeedbackVector::kDummyKeyedLoadICSlot));
slot = spec.AddStoreICSlot();
- DCHECK_EQ(slot, FeedbackVectorSlot(TypeFeedbackVector::kDummyStoreICSlot));
+ DCHECK_EQ(slot, FeedbackVectorSlot(FeedbackVector::kDummyStoreICSlot));
slot = spec.AddKeyedStoreICSlot();
DCHECK_EQ(slot,
- FeedbackVectorSlot(TypeFeedbackVector::kDummyKeyedStoreICSlot));
+ FeedbackVectorSlot(FeedbackVector::kDummyKeyedStoreICSlot));
- Handle<TypeFeedbackMetadata> dummy_metadata =
- TypeFeedbackMetadata::New(isolate(), &spec);
- Handle<TypeFeedbackVector> dummy_vector =
- TypeFeedbackVector::New(isolate(), dummy_metadata);
+ Handle<FeedbackMetadata> dummy_metadata =
+ FeedbackMetadata::New(isolate(), &spec);
+ Handle<FeedbackVector> dummy_vector =
+ FeedbackVector::New(isolate(), dummy_metadata);
set_dummy_vector(*dummy_vector);
@@ -2794,27 +2794,27 @@ void Heap::CreateInitialObjects() {
}
{
// Create a canonical empty TypeFeedbackVector, which is shared by all
// functions that don't need actual type feedback slots. Note however
// that all these functions will share the same invocation count, but
// that shouldn't matter since we only use the invocation count to
// relativize the absolute call counts, but we can only have call counts
// if we have actual feedback slots.
- Handle<FixedArray> empty_type_feedback_vector = factory->NewFixedArray(
- TypeFeedbackVector::kReservedIndexCount, TENURED);
- empty_type_feedback_vector->set(TypeFeedbackVector::kMetadataIndex,
+ Handle<FixedArray> empty_feedback_vector = factory->NewFixedArray(
+ FeedbackVector::kReservedIndexCount, TENURED);
+ empty_feedback_vector->set(FeedbackVector::kMetadataIndex,
empty_fixed_array());
- empty_type_feedback_vector->set(TypeFeedbackVector::kInvocationCountIndex,
+ empty_feedback_vector->set(FeedbackVector::kInvocationCountIndex,
Smi::kZero);
- empty_type_feedback_vector->set_map(type_feedback_vector_map());
- set_empty_type_feedback_vector(*empty_type_feedback_vector);
+ empty_feedback_vector->set_map(feedback_vector_map());
+ set_empty_feedback_vector(*empty_feedback_vector);
// We use a canonical empty LiteralsArray for all functions that neither
// have literals nor need a TypeFeedbackVector (besides the invocation
// count special slot).
Handle<FixedArray> empty_literals_array =
factory->NewFixedArray(1, TENURED);
- empty_literals_array->set(0, *empty_type_feedback_vector);
+ empty_literals_array->set(0, *empty_feedback_vector);
set_empty_literals_array(*empty_literals_array);
}
@@ -2794,27 +2794,27 @@ void Heap::CreateInitialObjects() {
}
{
- // Create a canonical empty TypeFeedbackVector, which is shared by all
+ // Create a canonical empty FeedbackVector, which is shared by all
// functions that don't need actual type feedback slots. Note however
// that all these functions will share the same invocation count, but
@@ -2794,27 +2794,27 @@ void Heap::CreateInitialObjects() {
// We use a canonical empty LiteralsArray for all functions that neither
- // have literals nor need a TypeFeedbackVector (besides the invocation
+ // have literals nor need a FeedbackVector (besides the invocation
// count special slot).
Handle<FixedArray> empty_literals_array =